summaryrefslogtreecommitdiffstats
path: root/kturtle/src/parser.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
commit0a6e0958c03e41c87b15557b6f407874f20c2f8d (patch)
tree2cdd58c4013b1be09cfcbb4ddae2b05712b9aeee /kturtle/src/parser.cpp
parent83f9dfafc157ff7823804b3ff457b43d021a5b4b (diff)
downloadtdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.tar.gz
tdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1157642 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kturtle/src/parser.cpp')
-rw-r--r--kturtle/src/parser.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kturtle/src/parser.cpp b/kturtle/src/parser.cpp
index ca1fafd7..07a33aea 100644
--- a/kturtle/src/parser.cpp
+++ b/kturtle/src/parser.cpp
@@ -20,7 +20,7 @@
// allmost every aspect of it is heavily changed by Cies Breijs.
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <kdebug.h>
#include <klocale.h>
@@ -28,7 +28,7 @@
#include "parser.h"
-Parser::Parser(QTextIStream& in)
+Parser::Parser(TQTextIStream& in)
{
lexer = new Lexer(in);
tree = new TreeNode();
@@ -198,8 +198,8 @@ TreeNode* Parser::Factor()
case tokString:
node = new TreeNode(currentToken, constantNode);
- { // extra scope to localize the QString 'str'
- QString str = currentToken.look;
+ { // extra scope to localize the TQString 'str'
+ TQString str = currentToken.look;
if ( currentToken.look.endsWith("\"") )
{
// cut off the quotes and store the value
@@ -238,7 +238,7 @@ TreeNode* Parser::Factor()
break;
default:
- QString s = currentToken.look;
+ TQString s = currentToken.look;
if ( s.isEmpty() || currentToken.type == tokEOF )
{
Error(currentToken, i18n("INTERNAL ERROR NR %1: please sent this Logo script to KTurtle developers").arg(1), 1020);
@@ -1075,7 +1075,7 @@ TreeNode* Parser::Other()
}
-void Parser::Error(Token& t, const QString& s, uint code)
+void Parser::Error(Token& t, const TQString& s, uint code)
{
emit ErrorMsg(t, s, code);
}